theory Example_Oil
imports
  "../Numerics/Euler_Affine"
  "../Numerics/Optimize_Float"
begin

subsection {* Oil reservoir in Affine arithmetic *}
text {*\label{sec:exampleoil}*}
approximate_affine oil "\<lambda>(y::real, z::real). (z, z*z + -3 * inverse (inverse 1000 + y*y))"

lemma oil_deriv_ok: fixes y::real
shows "1 / 1000 + y*y = 0 \<longleftrightarrow> False"
proof -
  have "1 / 1000 + y*y > 0"
    by (auto intro!: add_pos_nonneg)
  thus ?thesis by auto
qed

lemma oil_fderiv: "((\<lambda>(y::real, z::real). (z, z * z + -3 * inverse (inverse 1000 + y * y))) has_derivative
   (case x of (y, z) \<Rightarrow> \<lambda>(dy, dz). (dz, 2 * dz * z + 6 * (inverse (inverse 1000 + y * y) * (dy * (y * inverse (inverse 1000 + y * y)))))))
   (at x within X)"
  by (auto intro!: derivative_eq_intros simp: oil_deriv_ok split_beta inverse_eq_divide)

approximate_affine oil_d "\<lambda>(y::real, z) (dy, dz). (dz, 2 * dz * z  + 6 * (inverse (inverse 1000 + y*y) * (dy * (y * inverse (inverse 1000 + y*y)))))"

abbreviation "oil_ivp \<equiv> \<lambda>optns args. uncurry_options oil optns (hd args) (tl args)"
abbreviation "oil_d_ivp \<equiv> \<lambda>optns args. uncurry_options oil_d optns (hd args) (hd (tl args)) (tl (tl args))"

interpretation oil: aform_approximate_ivp
  oil_ivp oil_d_ivp
  "\<lambda>(y::real, z::real). (z, z*z + -3 * inverse (inverse 1000 + y*y))"
  "\<lambda>(y::real, z) (dy, dz).
    (dz, 2 * dz * z  + 6 * (inverse (inverse 1000 + y*y) * (dy * (y * inverse (inverse 1000 + y*y)))))"
  apply standard
  apply (rule oil[THEN Joints2_JointsI])
  unfolding list.sel
  apply assumption apply assumption
  apply (drule length_set_of_apprs, simp)--"TODO: prove in affine-approximation"
  apply (rule oil_fderiv)
  apply (rule oil_d[THEN Joints2_JointsI]) apply assumption apply assumption
  apply (drule length_set_of_apprs, simp)--"TODO: prove in affine-approximation"
  apply (auto intro!: continuous_intros simp: split_beta oil_deriv_ok)
  done

definition "rough_optns = default_optns
    \<lparr> precision := 50,
      tolerance := FloatR 1 (- 3),
      stepsize  := FloatR 1 (- 9),
      result_fun := ivls_result 20 110,
      iterations := 20,
      widening_mod := 20,
      printing_fun := (\<lambda>_ _ _. ())\<rparr>"

definition "oiltest_rough =
  (\<lambda>_::unit. euler_series_result oil_ivp oil_d_ivp rough_optns 0
      (aform_of_point (10, 0)) 22000)"

lemma "oiltest_rough () =
  Some (FloatR 175831 (- 12),
       [(FloatR 174951 (- 12), (FloatR (- 899741) (- 17), FloatR (- 666307) (- 21)),
         (FloatR (- 793547) (- 17), FloatR (- 591743) (- 21)), FloatR 175831 (- 12),
         (FloatR (- 899741) (- 17), FloatR (- 658317) (- 21)), FloatR (- 801547) (- 17),
         FloatR (- 591821) (- 21)),
        (FloatR 174071 (- 12), (FloatR (- 890848) (- 17), FloatR (- 674567) (- 21)),
         (FloatR (- 785451) (- 17), FloatR (- 599104) (- 21)), FloatR 174951 (- 12),
         (FloatR (- 890848) (- 17), FloatR (- 666230) (- 21)), FloatR (- 793551) (- 17),
         FloatR (- 599183) (- 21)),
        (FloatR 173191 (- 12), (FloatR (- 881846) (- 17), FloatR (- 683203) (- 21)),
         (FloatR (- 777248) (- 17), FloatR (- 606801) (- 21)), FloatR 174071 (- 12),
         (FloatR (- 881846) (- 17), FloatR (- 674489) (- 21)), FloatR (- 785455) (- 17),
         FloatR (- 606882) (- 21)),
        (FloatR 172311 (- 12), (FloatR (- 872731) (- 17), FloatR (- 692248) (- 21)),
         (FloatR (- 768935) (- 17), FloatR (- 614865) (- 21)), FloatR 173191 (- 12),
         (FloatR (- 872731) (- 17), FloatR (- 683123) (- 21)), FloatR (- 777252) (- 17),
         FloatR (- 614947) (- 21)),
        (FloatR 171431 (- 12), (FloatR (- 863498) (- 17), FloatR (- 701740) (- 21)),
         (FloatR (- 760505) (- 17), FloatR (- 623329) (- 21)), FloatR 172311 (- 12),
         (FloatR (- 863498) (- 17), FloatR (- 692166) (- 21)), FloatR (- 768939) (- 17),
         FloatR (- 623413) (- 21)),
        (FloatR 170551 (- 12), (FloatR (- 854140) (- 17), FloatR (- 711722) (- 21)),
         (FloatR (- 751953) (- 17), FloatR (- 632231) (- 21)), FloatR 171431 (- 12),
         (FloatR (- 854140) (- 17), FloatR (- 701656) (- 21)), FloatR (- 760510) (- 17),
         FloatR (- 632318) (- 21)),
        (FloatR 169671 (- 12), (FloatR (- 844651) (- 17), FloatR (- 722245) (- 21)),
         (FloatR (- 743271) (- 17), FloatR (- 641616) (- 21)), FloatR 170551 (- 12),
         (FloatR (- 844651) (- 17), FloatR (- 711637) (- 21)), FloatR (- 751957) (- 17),
         FloatR (- 641705) (- 21)),
        (FloatR 168791 (- 12), (FloatR (- 835025) (- 17), FloatR (- 733366) (- 21)),
         (FloatR (- 734452) (- 17), FloatR (- 651534) (- 21)), FloatR 169671 (- 12),
         (FloatR (- 835025) (- 17), FloatR (- 722158) (- 21)), FloatR (- 743275) (- 17),
         FloatR (- 651624) (- 21)),
        (FloatR 167911 (- 12), (FloatR (- 825253) (- 17), FloatR (- 745150) (- 21)),
         (FloatR (- 725487) (- 17), FloatR (- 662041) (- 21)), FloatR 168791 (- 12),
         (FloatR (- 825253) (- 17), FloatR (- 733276) (- 21)), FloatR (- 734456) (- 17),
         FloatR (- 662134) (- 21)),
        (FloatR 167031 (- 12), (FloatR (- 815328) (- 17), FloatR (- 757674) (- 21)),
         (FloatR (- 716368) (- 17), FloatR (- 673205) (- 21)), FloatR 167911 (- 12),
         (FloatR (- 815328) (- 17), FloatR (- 745058) (- 21)), FloatR (- 725491) (- 17),
         FloatR (- 673299) (- 21)),
        (FloatR 166151 (- 12), (FloatR (- 805240) (- 17), FloatR (- 771028) (- 21)),
         (FloatR (- 707083) (- 17), FloatR (- 685101) (- 21)), FloatR 167031 (- 12),
         (FloatR (- 805240) (- 17), FloatR (- 757580) (- 21)), FloatR (- 716372) (- 17),
         FloatR (- 685198) (- 21)),
        (FloatR 165271 (- 12), (FloatR (- 794978) (- 17), FloatR (- 785316) (- 21)),
         (FloatR (- 697622) (- 17), FloatR (- 697820) (- 21)), FloatR 166151 (- 12),
         (FloatR (- 794978) (- 17), FloatR (- 770931) (- 21)), FloatR (- 707088) (- 17),
         FloatR (- 697920) (- 21)),
        (FloatR 164391 (- 12), (FloatR (- 784531) (- 17), FloatR (- 800661) (- 21)),
         (FloatR (- 687970) (- 17), FloatR (- 711467) (- 21)), FloatR 165271 (- 12),
         (FloatR (- 784531) (- 17), FloatR (- 785216) (- 21)), FloatR (- 697626) (- 17),
         FloatR (- 711570) (- 21)),
        (FloatR 163511 (- 12), (FloatR (- 773884) (- 17), FloatR (- 817211) (- 21)),
         (FloatR (- 678114) (- 17), FloatR (- 726165) (- 21)), FloatR 164391 (- 12),
         (FloatR (- 773884) (- 17), FloatR (- 800559) (- 21)), FloatR (- 687975) (- 17),
         FloatR (- 726271) (- 21)),
        (FloatR 162631 (- 12), (FloatR (- 763024) (- 17), FloatR (- 835141) (- 21)),
         (FloatR (- 668034) (- 17), FloatR (- 742062) (- 21)), FloatR 163511 (- 12),
         (FloatR (- 763024) (- 17), FloatR (- 817105) (- 21)), FloatR (- 678118) (- 17),
         FloatR (- 742171) (- 21)),
        (FloatR 161751 (- 12), (FloatR (- 751933) (- 17), FloatR (- 854663) (- 21)),
         (FloatR (- 657713) (- 17), FloatR (- 759332) (- 21)), FloatR 162631 (- 12),
         (FloatR (- 751933) (- 17), FloatR (- 835032) (- 21)), FloatR (- 668039) (- 17),
         FloatR (- 759444) (- 21)),
        (FloatR 160871 (- 12), (FloatR (- 740591) (- 17), FloatR (- 876032) (- 21)),
         (FloatR (- 647126) (- 17), FloatR (- 778186) (- 21)), FloatR 161751 (- 12),
         (FloatR (- 740591) (- 17), FloatR (- 854550) (- 21)), FloatR (- 657717) (- 17),
         FloatR (- 778302) (- 21)),
        (FloatR 159991 (- 12), (FloatR (- 728974) (- 17), FloatR (- 899562) (- 21)),
         (FloatR (- 636247) (- 17), FloatR (- 798881) (- 21)), FloatR 160871 (- 12),
         (FloatR (- 728974) (- 17), FloatR (- 875915) (- 21)), FloatR (- 647131) (- 17),
         FloatR (- 799001) (- 21)),
        (FloatR 159111 (- 12), (FloatR (- 717056) (- 17), FloatR (- 925642) (- 21)),
         (FloatR (- 625045) (- 17), FloatR (- 821726) (- 21)), FloatR 159991 (- 12),
         (FloatR (- 717056) (- 17), FloatR (- 899441) (- 21)), FloatR (- 636252) (- 17),
         FloatR (- 821851) (- 21)),
        (FloatR 158231 (- 12), (FloatR (- 704806) (- 17), FloatR (- 954755) (- 21)),
         (FloatR (- 613482) (- 17), FloatR (- 847108) (- 21)), FloatR 159111 (- 12),
         (FloatR (- 704806) (- 17), FloatR (- 925515) (- 21)), FloatR (- 625050) (- 17),
         FloatR (- 847237) (- 21)),
        (FloatR 157351 (- 12), (FloatR (- 692186) (- 17), FloatR (- 987512) (- 21)),
         (FloatR (- 601515) (- 17), FloatR (- 875505) (- 21)), FloatR 158231 (- 12),
         (FloatR (- 692186) (- 17), FloatR (- 954623) (- 21)), FloatR (- 613487) (- 17),
         FloatR (- 875640) (- 21)),
        (FloatR 156471 (- 12), (FloatR (- 679151) (- 17), FloatR (- 1024697) (- 21)),
         (FloatR (- 589089) (- 17), FloatR (- 907522) (- 21)), FloatR 157351 (- 12),
         (FloatR (- 679151) (- 17), FloatR (- 987375) (- 21)), FloatR (- 601520) (- 17),
         FloatR (- 907663) (- 21)),
        (FloatR 155591 (- 12), (FloatR (- 665648) (- 17), FloatR (- 533662) (- 20)),
         (FloatR (- 576139) (- 17), FloatR (- 943929) (- 21)), FloatR 156471 (- 12),
         (FloatR (- 665648) (- 17), FloatR (- 1024553) (- 21)), FloatR (- 589094) (- 17),
         FloatR (- 944077) (- 21)),
        (FloatR 154711 (- 12), (FloatR (- 651610) (- 17), FloatR (- 558366) (- 20)),
         (FloatR (- 562584) (- 17), FloatR (- 985725) (- 21)), FloatR 155591 (- 12),
         (FloatR (- 651610) (- 17), FloatR (- 533586) (- 20)), FloatR (- 576144) (- 17),
         FloatR (- 985881) (- 21)),
        (FloatR 153831 (- 12), (FloatR (- 636956) (- 17), FloatR (- 587361) (- 20)),
         (FloatR (- 548324) (- 17), FloatR (- 1034224) (- 21)), FloatR 154711 (- 12),
         (FloatR (- 636956) (- 17), FloatR (- 558286) (- 20)), FloatR (- 562589) (- 17),
         FloatR (- 1034389) (- 21)),
        (FloatR 152951 (- 12), (FloatR (- 621583) (- 17), FloatR (- 621886) (- 20)),
         (FloatR (- 533229) (- 17), FloatR (- 545594) (- 20)), FloatR 153831 (- 12),
         (FloatR (- 621583) (- 17), FloatR (- 587276) (- 20)), FloatR (- 548329) (- 17),
         FloatR (- 545681) (- 20)),
        (FloatR 152071 (- 12), (FloatR (- 605361) (- 17), FloatR (- 663687) (- 20)),
         (FloatR (- 1034263) (- 18), FloatR (- 579517) (- 20)), FloatR 152951 (- 12),
         (FloatR (- 605361) (- 17), FloatR (- 621794) (- 20)), FloatR (- 533234) (- 17),
         FloatR (- 579611) (- 20)),
        (FloatR 151191 (- 12), (FloatR (- 588119) (- 17), FloatR (- 715306) (- 20)),
         (FloatR (- 999617) (- 18), FloatR (- 620582) (- 20)), FloatR 152071 (- 12),
         (FloatR (- 588119) (- 17), FloatR (- 663587) (- 20)), FloatR (- 1034274) (- 18),
         FloatR (- 620685) (- 20)),
        (FloatR 150311 (- 12), (FloatR (- 569629) (- 17), FloatR (- 780586) (- 20)),
         (FloatR (- 961911) (- 18), FloatR (- 671256) (- 20)), FloatR 151191 (- 12),
         (FloatR (- 569629) (- 17), FloatR (- 715197) (- 20)), FloatR (- 999628) (- 18),
         FloatR (- 671370) (- 20)),
        (FloatR 149431 (- 12), (FloatR (- 549580) (- 17), FloatR (- 865610) (- 20)),
         (FloatR (- 920285) (- 18), FloatR (- 735257) (- 20)), FloatR 150311 (- 12),
         (FloatR (- 549580) (- 17), FloatR (- 780464) (- 20)), FloatR (- 961922) (- 18),
         FloatR (- 735385) (- 20)),
        (FloatR 148551 (- 12), (FloatR (- 527531) (- 17), FloatR (- 980602) (- 20)),
         (FloatR (- 873468) (- 18), FloatR (- 818447) (- 20)), FloatR 149431 (- 12),
         (FloatR (- 527530) (- 17), FloatR (- 865471) (- 20)), FloatR (- 920297) (- 18),
         FloatR (- 818595) (- 20)),
        (FloatR 147671 (- 12), (FloatR (- 1005650) (- 18), FloatR (- 572069) (- 19)),
         (FloatR (- 819476) (- 18), FloatR (- 930637) (- 20)), FloatR 148551 (- 12),
         (FloatR (- 1005649) (- 18), FloatR (- 980439) (- 20)), FloatR (- 873480) (- 18),
         FloatR (- 930815) (- 20)),
        (FloatR 146791 (- 12), (FloatR (- 948872) (- 18), FloatR (- 696902) (- 19)),
         (FloatR (- 754961) (- 18), FloatR (- 544773) (- 19)), FloatR 147671 (- 12),
         (FloatR (- 948871) (- 18), FloatR (- 571968) (- 19)), FloatR (- 819489) (- 18),
         FloatR (- 544887) (- 19)),
        (FloatR 145911 (- 12), (FloatR (- 881238) (- 18), FloatR (- 909366) (- 19)),
         (FloatR (- 673607) (- 18), FloatR (- 665379) (- 19)), FloatR 146791 (- 12),
         (FloatR (- 881238) (- 18), FloatR (- 696766) (- 19)), FloatR (- 754977) (- 18),
         FloatR (- 665541) (- 19)),
        (FloatR 145031 (- 12), (FloatR (- 796106) (- 18), FloatR (- 676194) (- 18)),
         (FloatR (- 561314) (- 18), FloatR (- 868852) (- 19)), FloatR 145911 (- 12),
         (FloatR (- 796105) (- 18), FloatR (- 909153) (- 19)), FloatR (- 673628) (- 18),
         FloatR (- 869126) (- 19)),
        (FloatR 144151 (- 12), (FloatR (- 678028) (- 18), FloatR (- 697052) (- 17)),
         (FloatR (- 747200) (- 19), FloatR (- 637694) (- 18)), FloatR 145031 (- 12),
         (FloatR (- 678025) (- 18), FloatR (- 675934) (- 18)), FloatR (- 561354) (- 18),
         FloatR (- 638108) (- 18)),
        (FloatR 35859 (- 10), (FloatR (- 949024) (- 19), FloatR (- 782952) (- 15)),
         (FloatR 809103 (- 23), FloatR (- 621866) (- 17)), FloatR 144151 (- 12),
         (FloatR (- 949003) (- 19), FloatR (- 696167) (- 17)), FloatR (- 747511) (- 19),
         FloatR (- 623437) (- 17)),
        (FloatR 17820 (- 9), (FloatR 794796 (- 23), FloatR (- 863739) (- 17)),
         (FloatR 704638 (- 20), FloatR (- 923149) (- 19)), FloatR 35859 (- 10),
         (FloatR 794796 (- 23), FloatR (- 863739) (- 17)), FloatR 808606 (- 23),
         FloatR (- 847811) (- 17)),
        (FloatR 17710 (- 9), (FloatR 704583 (- 20), FloatR (- 923233) (- 19)),
         (FloatR 1040854 (- 20), FloatR (- 680113) (- 19)), FloatR 17820 (- 9),
         (FloatR 704583 (- 20), FloatR (- 923232) (- 19)), FloatR 704638 (- 20),
         FloatR (- 923150) (- 19)),
        (FloatR 17600 (- 9), (FloatR 1040826 (- 20), FloatR (- 680135) (- 19)),
         (FloatR 653079 (- 19), FloatR (- 565606) (- 19)), FloatR 17710 (- 9),
         (FloatR 1040826 (- 20), FloatR (- 680135) (- 19)), FloatR 1040854 (- 20),
         FloatR (- 680113) (- 19)),
        (FloatR 17490 (- 9), (FloatR 653069 (- 19), FloatR (- 565616) (- 19)),
         (FloatR 766522 (- 19), FloatR (- 990470) (- 20)), FloatR 17600 (- 9),
         (FloatR 653069 (- 19), FloatR (- 565616) (- 19)), FloatR 653079 (- 19),
         FloatR (- 565606) (- 19)),
        (FloatR 17380 (- 9), (FloatR 766515 (- 19), FloatR (- 990482) (- 20)),
         (FloatR 867382 (- 19), FloatR (- 892557) (- 20)), FloatR 17490 (- 9),
         (FloatR 766515 (- 19), FloatR (- 990482) (- 20)), FloatR 766522 (- 19),
         FloatR (- 990470) (- 20)),
        (FloatR 17270 (- 9), (FloatR 867376 (- 19), FloatR (- 892565) (- 20)),
         (FloatR 959155 (- 19), FloatR (- 819290) (- 20)), FloatR 17380 (- 9),
         (FloatR 867376 (- 19), FloatR (- 892565) (- 20)), FloatR 867382 (- 19),
         FloatR (- 892557) (- 20)),
        (FloatR 17160 (- 9), (FloatR 959150 (- 19), FloatR (- 819295) (- 20)),
         (FloatR 1043960 (- 19), FloatR (- 761757) (- 20)), FloatR 17270 (- 9),
         (FloatR 959150 (- 19), FloatR (- 819295) (- 20)), FloatR 959155 (- 19),
         FloatR (- 819290) (- 20)),
        (FloatR 17050 (- 9), (FloatR 1043956 (- 19), FloatR (- 761761) (- 20)),
         (FloatR 561599 (- 18), FloatR (- 715002) (- 20)), FloatR 17160 (- 9),
         (FloatR 1043956 (- 19), FloatR (- 761761) (- 20)), FloatR 1043960 (- 19),
         FloatR (- 761757) (- 20)),
        (FloatR 16940 (- 9), (FloatR 561596 (- 18), FloatR (- 715005) (- 20)),
         (FloatR 598926 (- 18), FloatR (- 676015) (- 20)), FloatR 17050 (- 9),
         (FloatR 561596 (- 18), FloatR (- 715005) (- 20)), FloatR 561599 (- 18),
         FloatR (- 715002) (- 20)),
        (FloatR 16830 (- 9), (FloatR 598923 (- 18), FloatR (- 676018) (- 20)),
         (FloatR 634322 (- 18), FloatR (- 642850) (- 20)), FloatR 16940 (- 9),
         (FloatR 598923 (- 18), FloatR (- 676018) (- 20)), FloatR 598926 (- 18),
         FloatR (- 676015) (- 20)),
        (FloatR 16720 (- 9), (FloatR 634319 (- 18), FloatR (- 642853) (- 20)),
         (FloatR 668062 (- 18), FloatR (- 614182) (- 20)), FloatR 16830 (- 9),
         (FloatR 634319 (- 18), FloatR (- 642853) (- 20)), FloatR 634322 (- 18),
         FloatR (- 642850) (- 20)),
        (FloatR 16610 (- 9), (FloatR 668060 (- 18), FloatR (- 614184) (- 20)),
         (FloatR 700362 (- 18), FloatR (- 589074) (- 20)), FloatR 16720 (- 9),
         (FloatR 668060 (- 18), FloatR (- 614184) (- 20)), FloatR 668062 (- 18),
         FloatR (- 614182) (- 20)),
        (FloatR 16500 (- 9), (FloatR 700360 (- 18), FloatR (- 589076) (- 20)),
         (FloatR 731393 (- 18), FloatR (- 566842) (- 20)), FloatR 16610 (- 9),
         (FloatR 700360 (- 18), FloatR (- 589076) (- 20)), FloatR 700362 (- 18),
         FloatR (- 589074) (- 20)),
        (FloatR 16390 (- 9), (FloatR 731391 (- 18), FloatR (- 566844) (- 20)),
         (FloatR 761295 (- 18), FloatR (- 546974) (- 20)), FloatR 16500 (- 9),
         (FloatR 731391 (- 18), FloatR (- 566844) (- 20)), FloatR 731393 (- 18),
         FloatR (- 566842) (- 20)),
        (FloatR 16280 (- 9), (FloatR 761293 (- 18), FloatR (- 546976) (- 20)),
         (FloatR 790185 (- 18), FloatR (- 529077) (- 20)), FloatR 16390 (- 9),
         (FloatR 761293 (- 18), FloatR (- 546976) (- 20)), FloatR 761295 (- 18),
         FloatR (- 546974) (- 20)),
        (FloatR 16170 (- 9), (FloatR 790183 (- 18), FloatR (- 529078) (- 20)),
         (FloatR 818160 (- 18), FloatR (- 1025688) (- 21)), FloatR 16280 (- 9),
         (FloatR 790183 (- 18), FloatR (- 529078) (- 20)), FloatR 790185 (- 18),
         FloatR (- 529077) (- 20)),
        (FloatR 16060 (- 9), (FloatR 818158 (- 18), FloatR (- 1025690) (- 21)),
         (FloatR 845301 (- 18), FloatR (- 996061) (- 21)), FloatR 16170 (- 9),
         (FloatR 818158 (- 18), FloatR (- 1025690) (- 21)), FloatR 818160 (- 18),
         FloatR (- 1025688) (- 21)),
        (FloatR 15950 (- 9), (FloatR 845299 (- 18), FloatR (- 996064) (- 21)),
         (FloatR 871681 (- 18), FloatR (- 968883) (- 21)), FloatR 16060 (- 9),
         (FloatR 845299 (- 18), FloatR (- 996064) (- 21)), FloatR 845301 (- 18),
         FloatR (- 996061) (- 21)),
        (FloatR 15840 (- 9), (FloatR 871679 (- 18), FloatR (- 968885) (- 21)),
         (FloatR 897360 (- 18), FloatR (- 943831) (- 21)), FloatR 15950 (- 9),
         (FloatR 871679 (- 18), FloatR (- 968885) (- 21)), FloatR 871681 (- 18),
         FloatR (- 968883) (- 21)),
        (FloatR 15730 (- 9), (FloatR 897358 (- 18), FloatR (- 943833) (- 21)),
         (FloatR 922392 (- 18), FloatR (- 920641) (- 21)), FloatR 15840 (- 9),
         (FloatR 897358 (- 18), FloatR (- 943833) (- 21)), FloatR 897360 (- 18),
         FloatR (- 943831) (- 21)),
        (FloatR 15620 (- 9), (FloatR 922390 (- 18), FloatR (- 920643) (- 21)),
         (FloatR 946823 (- 18), FloatR (- 899093) (- 21)), FloatR 15730 (- 9),
         (FloatR 922390 (- 18), FloatR (- 920643) (- 21)), FloatR 922392 (- 18),
         FloatR (- 920641) (- 21)),
        (FloatR 15510 (- 9), (FloatR 946821 (- 18), FloatR (- 899094) (- 21)),
         (FloatR 970696 (- 18), FloatR (- 879000) (- 21)), FloatR 15620 (- 9),
         (FloatR 946821 (- 18), FloatR (- 899094) (- 21)), FloatR 946823 (- 18),
         FloatR (- 899093) (- 21)),
        (FloatR 15400 (- 9), (FloatR 970694 (- 18), FloatR (- 879002) (- 21)),
         (FloatR 994047 (- 18), FloatR (- 860207) (- 21)), FloatR 15510 (- 9),
         (FloatR 970694 (- 18), FloatR (- 879002) (- 21)), FloatR 970696 (- 18),
         FloatR (- 879000) (- 21)),
        (FloatR 15290 (- 9), (FloatR 994045 (- 18), FloatR (- 860208) (- 21)),
         (FloatR 1016909 (- 18), FloatR (- 842577) (- 21)), FloatR 15400 (- 9),
         (FloatR 994045 (- 18), FloatR (- 860208) (- 21)), FloatR 994047 (- 18),
         FloatR (- 860207) (- 21)),
        (FloatR 15180 (- 9), (FloatR 1016907 (- 18), FloatR (- 842578) (- 21)),
         (FloatR 1039312 (- 18), FloatR (- 825995) (- 21)), FloatR 15290 (- 9),
         (FloatR 1016907 (- 18), FloatR (- 842578) (- 21)), FloatR 1016909 (- 18),
         FloatR (- 842577) (- 21)),
        (FloatR 15070 (- 9), (FloatR 1039310 (- 18), FloatR (- 825997) (- 21)),
         (FloatR 530641 (- 17), FloatR (- 810362) (- 21)), FloatR 15180 (- 9),
         (FloatR 1039310 (- 18), FloatR (- 825997) (- 21)), FloatR 1039312 (- 18),
         FloatR (- 825995) (- 21)),
        (FloatR 14960 (- 9), (FloatR 530640 (- 17), FloatR (- 810363) (- 21)),
         (FloatR 541423 (- 17), FloatR (- 795589) (- 21)), FloatR 15070 (- 9),
         (FloatR 530640 (- 17), FloatR (- 810363) (- 21)), FloatR 530641 (- 17),
         FloatR (- 810362) (- 21)),
        (FloatR 14850 (- 9), (FloatR 541421 (- 17), FloatR (- 795590) (- 21)),
         (FloatR 552011 (- 17), FloatR (- 781600) (- 21)), FloatR 14960 (- 9),
         (FloatR 541421 (- 17), FloatR (- 795590) (- 21)), FloatR 541423 (- 17),
         FloatR (- 795589) (- 21)),
        (FloatR 14740 (- 9), (FloatR 552010 (- 17), FloatR (- 781602) (- 21)),
         (FloatR 562416 (- 17), FloatR (- 768329) (- 21)), FloatR 14850 (- 9),
         (FloatR 552010 (- 17), FloatR (- 781602) (- 21)), FloatR 552011 (- 17),
         FloatR (- 781600) (- 21)),
        (FloatR 14630 (- 9), (FloatR 562415 (- 17), FloatR (- 768330) (- 21)),
         (FloatR 572648 (- 17), FloatR (- 755715) (- 21)), FloatR 14740 (- 9),
         (FloatR 562415 (- 17), FloatR (- 768330) (- 21)), FloatR 562416 (- 17),
         FloatR (- 768329) (- 21)),
        (FloatR 14520 (- 9), (FloatR 572646 (- 17), FloatR (- 755716) (- 21)),
         (FloatR 582714 (- 17), FloatR (- 743706) (- 21)), FloatR 14630 (- 9),
         (FloatR 572646 (- 17), FloatR (- 755716) (- 21)), FloatR 572648 (- 17),
         FloatR (- 755715) (- 21)),
        (FloatR 14410 (- 9), (FloatR 582713 (- 17), FloatR (- 743707) (- 21)),
         (FloatR 592623 (- 17), FloatR (- 732255) (- 21)), FloatR 14520 (- 9),
         (FloatR 582713 (- 17), FloatR (- 743707) (- 21)), FloatR 582714 (- 17),
         FloatR (- 743706) (- 21)),
        (FloatR 14300 (- 9), (FloatR 592621 (- 17), FloatR (- 732256) (- 21)),
         (FloatR 602381 (- 17), FloatR (- 721319) (- 21)), FloatR 14410 (- 9),
         (FloatR 592621 (- 17), FloatR (- 732256) (- 21)), FloatR 592623 (- 17),
         FloatR (- 732255) (- 21)),
        (FloatR 14190 (- 9), (FloatR 602380 (- 17), FloatR (- 721321) (- 21)),
         (FloatR 611996 (- 17), FloatR (- 710862) (- 21)), FloatR 14300 (- 9),
         (FloatR 602380 (- 17), FloatR (- 721321) (- 21)), FloatR 602381 (- 17),
         FloatR (- 721319) (- 21)),
        (FloatR 14080 (- 9), (FloatR 611995 (- 17), FloatR (- 710864) (- 21)),
         (FloatR 621474 (- 17), FloatR (- 700849) (- 21)), FloatR 14190 (- 9),
         (FloatR 611995 (- 17), FloatR (- 710864) (- 21)), FloatR 611996 (- 17),
         FloatR (- 710862) (- 21)),
        (FloatR 13970 (- 9), (FloatR 621473 (- 17), FloatR (- 700851) (- 21)),
         (FloatR 630820 (- 17), FloatR (- 691250) (- 21)), FloatR 14080 (- 9),
         (FloatR 621473 (- 17), FloatR (- 700851) (- 21)), FloatR 621474 (- 17),
         FloatR (- 700849) (- 21)),
        (FloatR 13860 (- 9), (FloatR 630818 (- 17), FloatR (- 691251) (- 21)),
         (FloatR 640039 (- 17), FloatR (- 682037) (- 21)), FloatR 13970 (- 9),
         (FloatR 630818 (- 17), FloatR (- 691251) (- 21)), FloatR 630820 (- 17),
         FloatR (- 691250) (- 21)),
        (FloatR 13750 (- 9), (FloatR 640038 (- 17), FloatR (- 682038) (- 21)),
         (FloatR 649138 (- 17), FloatR (- 673184) (- 21)), FloatR 13860 (- 9),
         (FloatR 640038 (- 17), FloatR (- 682038) (- 21)), FloatR 640039 (- 17),
         FloatR (- 682037) (- 21)),
        (FloatR 13640 (- 9), (FloatR 649137 (- 17), FloatR (- 673185) (- 21)),
         (FloatR 658119 (- 17), FloatR (- 664668) (- 21)), FloatR 13750 (- 9),
         (FloatR 649137 (- 17), FloatR (- 673185) (- 21)), FloatR 649138 (- 17),
         FloatR (- 673184) (- 21)),
        (FloatR 13530 (- 9), (FloatR 658118 (- 17), FloatR (- 664669) (- 21)),
         (FloatR 666989 (- 17), FloatR (- 656469) (- 21)), FloatR 13640 (- 9),
         (FloatR 658118 (- 17), FloatR (- 664669) (- 21)), FloatR 658119 (- 17),
         FloatR (- 664668) (- 21)),
        (FloatR 13420 (- 9), (FloatR 666988 (- 17), FloatR (- 656470) (- 21)),
         (FloatR 675751 (- 17), FloatR (- 648567) (- 21)), FloatR 13530 (- 9),
         (FloatR 666988 (- 17), FloatR (- 656470) (- 21)), FloatR 666989 (- 17),
         FloatR (- 656469) (- 21)),
        (FloatR 13310 (- 9), (FloatR 675749 (- 17), FloatR (- 648569) (- 21)),
         (FloatR 684408 (- 17), FloatR (- 640946) (- 21)), FloatR 13420 (- 9),
         (FloatR 675749 (- 17), FloatR (- 648569) (- 21)), FloatR 675751 (- 17),
         FloatR (- 648567) (- 21)),
        (FloatR 13200 (- 9), (FloatR 684407 (- 17), FloatR (- 640947) (- 21)),
         (FloatR 692965 (- 17), FloatR (- 633587) (- 21)), FloatR 13310 (- 9),
         (FloatR 684407 (- 17), FloatR (- 640947) (- 21)), FloatR 684408 (- 17),
         FloatR (- 640946) (- 21)),
        (FloatR 13090 (- 9), (FloatR 692964 (- 17), FloatR (- 633588) (- 21)),
         (FloatR 701424 (- 17), FloatR (- 626477) (- 21)), FloatR 13200 (- 9),
         (FloatR 692964 (- 17), FloatR (- 633588) (- 21)), FloatR 692965 (- 17),
         FloatR (- 633587) (- 21)),
        (FloatR 12980 (- 9), (FloatR 701423 (- 17), FloatR (- 626479) (- 21)),
         (FloatR 709790 (- 17), FloatR (- 619603) (- 21)), FloatR 13090 (- 9),
         (FloatR 701423 (- 17), FloatR (- 626479) (- 21)), FloatR 701424 (- 17),
         FloatR (- 626477) (- 21)),
        (FloatR 12870 (- 9), (FloatR 709789 (- 17), FloatR (- 619604) (- 21)),
         (FloatR 718065 (- 17), FloatR (- 612950) (- 21)), FloatR 12980 (- 9),
         (FloatR 709789 (- 17), FloatR (- 619604) (- 21)), FloatR 709790 (- 17),
         FloatR (- 619603) (- 21)),
        (FloatR 12760 (- 9), (FloatR 718064 (- 17), FloatR (- 612951) (- 21)),
         (FloatR 726252 (- 17), FloatR (- 606508) (- 21)), FloatR 12870 (- 9),
         (FloatR 718064 (- 17), FloatR (- 612951) (- 21)), FloatR 718065 (- 17),
         FloatR (- 612950) (- 21)),
        (FloatR 12650 (- 9), (FloatR 726251 (- 17), FloatR (- 606509) (- 21)),
         (FloatR 734354 (- 17), FloatR (- 600265) (- 21)), FloatR 12760 (- 9),
         (FloatR 726251 (- 17), FloatR (- 606509) (- 21)), FloatR 726252 (- 17),
         FloatR (- 606508) (- 21)),
        (FloatR 12540 (- 9), (FloatR 734353 (- 17), FloatR (- 600266) (- 21)),
         (FloatR 742373 (- 17), FloatR (- 594211) (- 21)), FloatR 12650 (- 9),
         (FloatR 734353 (- 17), FloatR (- 600266) (- 21)), FloatR 734354 (- 17),
         FloatR (- 600265) (- 21)),
        (FloatR 12430 (- 9), (FloatR 742372 (- 17), FloatR (- 594212) (- 21)),
         (FloatR 750313 (- 17), FloatR (- 588337) (- 21)), FloatR 12540 (- 9),
         (FloatR 742372 (- 17), FloatR (- 594212) (- 21)), FloatR 742373 (- 17),
         FloatR (- 594211) (- 21)),
        (FloatR 12320 (- 9), (FloatR 750312 (- 17), FloatR (- 588339) (- 21)),
         (FloatR 758174 (- 17), FloatR (- 582635) (- 21)), FloatR 12430 (- 9),
         (FloatR 750312 (- 17), FloatR (- 588339) (- 21)), FloatR 750313 (- 17),
         FloatR (- 588337) (- 21)),
        (FloatR 12210 (- 9), (FloatR 758173 (- 17), FloatR (- 582636) (- 21)),
         (FloatR 765960 (- 17), FloatR (- 577095) (- 21)), FloatR 12320 (- 9),
         (FloatR 758173 (- 17), FloatR (- 582636) (- 21)), FloatR 758174 (- 17),
         FloatR (- 582635) (- 21)),
        (FloatR 12100 (- 9), (FloatR 765959 (- 17), FloatR (- 577096) (- 21)),
         (FloatR 773673 (- 17), FloatR (- 571710) (- 21)), FloatR 12210 (- 9),
         (FloatR 765959 (- 17), FloatR (- 577096) (- 21)), FloatR 765960 (- 17),
         FloatR (- 577095) (- 21)),
        (FloatR 11990 (- 9), (FloatR 773672 (- 17), FloatR (- 571711) (- 21)),
         (FloatR 781314 (- 17), FloatR (- 566473) (- 21)), FloatR 12100 (- 9),
         (FloatR 773672 (- 17), FloatR (- 571711) (- 21)), FloatR 773673 (- 17),
         FloatR (- 571710) (- 21)),
        (FloatR 11880 (- 9), (FloatR 781313 (- 17), FloatR (- 566474) (- 21)),
         (FloatR 788887 (- 17), FloatR (- 561378) (- 21)), FloatR 11990 (- 9),
         (FloatR 781313 (- 17), FloatR (- 566474) (- 21)), FloatR 781314 (- 17),
         FloatR (- 566473) (- 21)),
        (FloatR 11770 (- 9), (FloatR 788886 (- 17), FloatR (- 561379) (- 21)),
         (FloatR 796391 (- 17), FloatR (- 556417) (- 21)), FloatR 11880 (- 9),
         (FloatR 788886 (- 17), FloatR (- 561379) (- 21)), FloatR 788887 (- 17),
         FloatR (- 561378) (- 21)),
        (FloatR 11660 (- 9), (FloatR 796390 (- 17), FloatR (- 556418) (- 21)),
         (FloatR 803830 (- 17), FloatR (- 551585) (- 21)), FloatR 11770 (- 9),
         (FloatR 796390 (- 17), FloatR (- 556418) (- 21)), FloatR 796391 (- 17),
         FloatR (- 556417) (- 21)),
        (FloatR 11550 (- 9), (FloatR 803829 (- 17), FloatR (- 551586) (- 21)),
         (FloatR 811205 (- 17), FloatR (- 546877) (- 21)), FloatR 11660 (- 9),
         (FloatR 803829 (- 17), FloatR (- 551586) (- 21)), FloatR 803830 (- 17),
         FloatR (- 551585) (- 21)),
        (FloatR 11440 (- 9), (FloatR 811204 (- 17), FloatR (- 546878) (- 21)),
         (FloatR 818517 (- 17), FloatR (- 542286) (- 21)), FloatR 11550 (- 9),
         (FloatR 811204 (- 17), FloatR (- 546878) (- 21)), FloatR 811205 (- 17),
         FloatR (- 546877) (- 21)),
        (FloatR 11330 (- 9), (FloatR 818516 (- 17), FloatR (- 542287) (- 21)),
         (FloatR 825769 (- 17), FloatR (- 537808) (- 21)), FloatR 11440 (- 9),
         (FloatR 818516 (- 17), FloatR (- 542287) (- 21)), FloatR 818517 (- 17),
         FloatR (- 542286) (- 21)),
        (FloatR 11220 (- 9), (FloatR 825768 (- 17), FloatR (- 537809) (- 21)),
         (FloatR 832961 (- 17), FloatR (- 533439) (- 21)), FloatR 11330 (- 9),
         (FloatR 825768 (- 17), FloatR (- 537809) (- 21)), FloatR 825769 (- 17),
         FloatR (- 537808) (- 21)),
        (FloatR 11110 (- 9), (FloatR 832960 (- 17), FloatR (- 533440) (- 21)),
         (FloatR 840095 (- 17), FloatR (- 529174) (- 21)), FloatR 11220 (- 9),
         (FloatR 832960 (- 17), FloatR (- 533440) (- 21)), FloatR 832961 (- 17),
         FloatR (- 533439) (- 21)),
        (FloatR 11000 (- 9), (FloatR 840094 (- 17), FloatR (- 529175) (- 21)),
         (FloatR 847172 (- 17), FloatR (- 525008) (- 21)), FloatR 11110 (- 9),
         (FloatR 840094 (- 17), FloatR (- 529175) (- 21)), FloatR 840095 (- 17),
         FloatR (- 529174) (- 21)),
        (FloatR 10890 (- 9), (FloatR 847171 (- 17), FloatR (- 525009) (- 21)),
         (FloatR 854195 (- 17), FloatR (- 1041875) (- 22)), FloatR 11000 (- 9),
         (FloatR 847171 (- 17), FloatR (- 525009) (- 21)), FloatR 847172 (- 17),
         FloatR (- 525008) (- 21)),
        (FloatR 10780 (- 9), (FloatR 854194 (- 17), FloatR (- 1041876) (- 22)),
         (FloatR 861163 (- 17), FloatR (- 1033918) (- 22)), FloatR 10890 (- 9),
         (FloatR 854194 (- 17), FloatR (- 1041876) (- 22)), FloatR 854195 (- 17),
         FloatR (- 1041875) (- 22)),
        (FloatR 10670 (- 9), (FloatR 861162 (- 17), FloatR (- 1033919) (- 22)),
         (FloatR 868078 (- 17), FloatR (- 1026137) (- 22)), FloatR 10780 (- 9),
         (FloatR 861162 (- 17), FloatR (- 1033919) (- 22)), FloatR 861163 (- 17),
         FloatR (- 1033918) (- 22)),
        (FloatR 10560 (- 9), (FloatR 868077 (- 17), FloatR (- 1026138) (- 22)),
         (FloatR 874942 (- 17), FloatR (- 1018525) (- 22)), FloatR 10670 (- 9),
         (FloatR 868077 (- 17), FloatR (- 1026138) (- 22)), FloatR 868078 (- 17),
         FloatR (- 1026137) (- 22)),
        (FloatR 10450 (- 9), (FloatR 874941 (- 17), FloatR (- 1018526) (- 22)),
         (FloatR 881755 (- 17), FloatR (- 1011076) (- 22)), FloatR 10560 (- 9),
         (FloatR 874941 (- 17), FloatR (- 1018526) (- 22)), FloatR 874942 (- 17),
         FloatR (- 1018525) (- 22)),
        (FloatR 10340 (- 9), (FloatR 881754 (- 17), FloatR (- 1011077) (- 22)),
         (FloatR 888519 (- 17), FloatR (- 1003783) (- 22)), FloatR 10450 (- 9),
         (FloatR 881754 (- 17), FloatR (- 1011077) (- 22)), FloatR 881755 (- 17),
         FloatR (- 1011076) (- 22)),
        (FloatR 10230 (- 9), (FloatR 888518 (- 17), FloatR (- 1003784) (- 22)),
         (FloatR 895234 (- 17), FloatR (- 996641) (- 22)), FloatR 10340 (- 9),
         (FloatR 888518 (- 17), FloatR (- 1003784) (- 22)), FloatR 888519 (- 17),
         FloatR (- 1003783) (- 22)),
        (FloatR 10120 (- 9), (FloatR 895233 (- 17), FloatR (- 996642) (- 22)),
         (FloatR 901902 (- 17), FloatR (- 989643) (- 22)), FloatR 10230 (- 9),
         (FloatR 895233 (- 17), FloatR (- 996642) (- 22)), FloatR 895234 (- 17),
         FloatR (- 996641) (- 22)),
        (FloatR 10010 (- 9), (FloatR 901901 (- 17), FloatR (- 989644) (- 22)),
         (FloatR 908523 (- 17), FloatR (- 982784) (- 22)), FloatR 10120 (- 9),
         (FloatR 901901 (- 17), FloatR (- 989644) (- 22)), FloatR 901902 (- 17),
         FloatR (- 989643) (- 22)),
        (FloatR 9900 (- 9), (FloatR 908522 (- 17), FloatR (- 982785) (- 22)),
         (FloatR 915099 (- 17), FloatR (- 976058) (- 22)), FloatR 10010 (- 9),
         (FloatR 908522 (- 17), FloatR (- 982785) (- 22)), FloatR 908523 (- 17),
         FloatR (- 982784) (- 22)),
        (FloatR 9790 (- 9), (FloatR 915098 (- 17), FloatR (- 976059) (- 22)),
         (FloatR 921629 (- 17), FloatR (- 969461) (- 22)), FloatR 9900 (- 9),
         (FloatR 915098 (- 17), FloatR (- 976059) (- 22)), FloatR 915099 (- 17),
         FloatR (- 976058) (- 22)),
        (FloatR 9680 (- 9), (FloatR 921628 (- 17), FloatR (- 969462) (- 22)),
         (FloatR 928117 (- 17), FloatR (- 962987) (- 22)), FloatR 9790 (- 9),
         (FloatR 921628 (- 17), FloatR (- 969462) (- 22)), FloatR 921629 (- 17),
         FloatR (- 969461) (- 22)),
        (FloatR 9570 (- 9), (FloatR 928115 (- 17), FloatR (- 962988) (- 22)),
         (FloatR 934560 (- 17), FloatR (- 956631) (- 22)), FloatR 9680 (- 9),
         (FloatR 928115 (- 17), FloatR (- 962988) (- 22)), FloatR 928117 (- 17),
         FloatR (- 962987) (- 22)),
        (FloatR 9460 (- 9), (FloatR 934559 (- 17), FloatR (- 956632) (- 22)),
         (FloatR 940962 (- 17), FloatR (- 950389) (- 22)), FloatR 9570 (- 9),
         (FloatR 934559 (- 17), FloatR (- 956632) (- 22)), FloatR 934560 (- 17),
         FloatR (- 956631) (- 22)),
        (FloatR 9350 (- 9), (FloatR 940961 (- 17), FloatR (- 950391) (- 22)),
         (FloatR 947322 (- 17), FloatR (- 944257) (- 22)), FloatR 9460 (- 9),
         (FloatR 940961 (- 17), FloatR (- 950391) (- 22)), FloatR 940962 (- 17),
         FloatR (- 950389) (- 22)),
        (FloatR 9240 (- 9), (FloatR 947321 (- 17), FloatR (- 944258) (- 22)),
         (FloatR 953642 (- 17), FloatR (- 938228) (- 22)), FloatR 9350 (- 9),
         (FloatR 947321 (- 17), FloatR (- 944258) (- 22)), FloatR 947322 (- 17),
         FloatR (- 944257) (- 22)),
        (FloatR 9130 (- 9), (FloatR 953641 (- 17), FloatR (- 938229) (- 22)),
         (FloatR 959921 (- 17), FloatR (- 932300) (- 22)), FloatR 9240 (- 9),
         (FloatR 953641 (- 17), FloatR (- 938229) (- 22)), FloatR 953642 (- 17),
         FloatR (- 938228) (- 22)),
        (FloatR 9020 (- 9), (FloatR 959920 (- 17), FloatR (- 932301) (- 22)),
         (FloatR 966161 (- 17), FloatR (- 926467) (- 22)), FloatR 9130 (- 9),
         (FloatR 959920 (- 17), FloatR (- 932301) (- 22)), FloatR 959921 (- 17),
         FloatR (- 932300) (- 22)),
        (FloatR 8910 (- 9), (FloatR 966159 (- 17), FloatR (- 926468) (- 22)),
         (FloatR 972361 (- 17), FloatR (- 920726) (- 22)), FloatR 9020 (- 9),
         (FloatR 966159 (- 17), FloatR (- 926468) (- 22)), FloatR 966161 (- 17),
         FloatR (- 926467) (- 22)),
        (FloatR 8800 (- 9), (FloatR 972360 (- 17), FloatR (- 920727) (- 22)),
         (FloatR 978524 (- 17), FloatR (- 915072) (- 22)), FloatR 8910 (- 9),
         (FloatR 972360 (- 17), FloatR (- 920727) (- 22)), FloatR 972361 (- 17),
         FloatR (- 920726) (- 22)),
        (FloatR 8690 (- 9), (FloatR 978523 (- 17), FloatR (- 915073) (- 22)),
         (FloatR 984649 (- 17), FloatR (- 909501) (- 22)), FloatR 8800 (- 9),
         (FloatR 978523 (- 17), FloatR (- 915073) (- 22)), FloatR 978524 (- 17),
         FloatR (- 915072) (- 22)),
        (FloatR 8580 (- 9), (FloatR 984648 (- 17), FloatR (- 909502) (- 22)),
         (FloatR 990737 (- 17), FloatR (- 904009) (- 22)), FloatR 8690 (- 9),
         (FloatR 984648 (- 17), FloatR (- 909502) (- 22)), FloatR 984649 (- 17),
         FloatR (- 909501) (- 22)),
        (FloatR 8470 (- 9), (FloatR 990736 (- 17), FloatR (- 904010) (- 22)),
         (FloatR 996788 (- 17), FloatR (- 898591) (- 22)), FloatR 8580 (- 9),
         (FloatR 990736 (- 17), FloatR (- 904010) (- 22)), FloatR 990737 (- 17),
         FloatR (- 904009) (- 22)),
        (FloatR 8360 (- 9), (FloatR 996787 (- 17), FloatR (- 898593) (- 22)),
         (FloatR 1002803 (- 17), FloatR (- 893244) (- 22)), FloatR 8470 (- 9),
         (FloatR 996787 (- 17), FloatR (- 898593) (- 22)), FloatR 996788 (- 17),
         FloatR (- 898591) (- 22)),
        (FloatR 8250 (- 9), (FloatR 1002802 (- 17), FloatR (- 893245) (- 22)),
         (FloatR 1008782 (- 17), FloatR (- 887963) (- 22)), FloatR 8360 (- 9),
         (FloatR 1002802 (- 17), FloatR (- 893245) (- 22)), FloatR 1002803 (- 17),
         FloatR (- 893244) (- 22)),
        (FloatR 8140 (- 9), (FloatR 1008781 (- 17), FloatR (- 887964) (- 22)),
         (FloatR 1014726 (- 17), FloatR (- 882744) (- 22)), FloatR 8250 (- 9),
         (FloatR 1008781 (- 17), FloatR (- 887964) (- 22)), FloatR 1008782 (- 17),
         FloatR (- 887963) (- 22)),
        (FloatR 8030 (- 9), (FloatR 1014725 (- 17), FloatR (- 882745) (- 22)),
         (FloatR 1020636 (- 17), FloatR (- 877582) (- 22)), FloatR 8140 (- 9),
         (FloatR 1014725 (- 17), FloatR (- 882745) (- 22)), FloatR 1014726 (- 17),
         FloatR (- 882744) (- 22)),
        (FloatR 7920 (- 9), (FloatR 1020635 (- 17), FloatR (- 877583) (- 22)),
         (FloatR 1026510 (- 17), FloatR (- 872474) (- 22)), FloatR 8030 (- 9),
         (FloatR 1020635 (- 17), FloatR (- 877583) (- 22)), FloatR 1020636 (- 17),
         FloatR (- 877582) (- 22)),
        (FloatR 7810 (- 9), (FloatR 1026509 (- 17), FloatR (- 872475) (- 22)),
         (FloatR 1032351 (- 17), FloatR (- 867414) (- 22)), FloatR 7920 (- 9),
         (FloatR 1026509 (- 17), FloatR (- 872475) (- 22)), FloatR 1026510 (- 17),
         FloatR (- 872474) (- 22)),
        (FloatR 7700 (- 9), (FloatR 1032350 (- 17), FloatR (- 867415) (- 22)),
         (FloatR 1038158 (- 17), FloatR (- 862398) (- 22)), FloatR 7810 (- 9),
         (FloatR 1032350 (- 17), FloatR (- 867415) (- 22)), FloatR 1032351 (- 17),
         FloatR (- 867414) (- 22)),
        (FloatR 7590 (- 9), (FloatR 1038157 (- 17), FloatR (- 862399) (- 22)),
         (FloatR 1043931 (- 17), FloatR (- 857421) (- 22)), FloatR 7700 (- 9),
         (FloatR 1038157 (- 17), FloatR (- 862399) (- 22)), FloatR 1038158 (- 17),
         FloatR (- 862398) (- 22)),
        (FloatR 7480 (- 9), (FloatR 1043930 (- 17), FloatR (- 857422) (- 22)),
         (FloatR 524836 (- 16), FloatR (- 852479) (- 22)), FloatR 7590 (- 9),
         (FloatR 1043930 (- 17), FloatR (- 857422) (- 22)), FloatR 1043931 (- 17),
         FloatR (- 857421) (- 22)),
        (FloatR 7370 (- 9), (FloatR 524835 (- 16), FloatR (- 852480) (- 22)),
         (FloatR 527689 (- 16), FloatR (- 847567) (- 22)), FloatR 7480 (- 9),
         (FloatR 524835 (- 16), FloatR (- 852480) (- 22)), FloatR 524836 (- 16),
         FloatR (- 852479) (- 22)),
        (FloatR 7260 (- 9), (FloatR 527688 (- 16), FloatR (- 847568) (- 22)),
         (FloatR 530526 (- 16), FloatR (- 842678) (- 22)), FloatR 7370 (- 9),
         (FloatR 527688 (- 16), FloatR (- 847568) (- 22)), FloatR 527689 (- 16),
         FloatR (- 847567) (- 22)),
        (FloatR 7150 (- 9), (FloatR 530525 (- 16), FloatR (- 842679) (- 22)),
         (FloatR 533347 (- 16), FloatR (- 837808) (- 22)), FloatR 7260 (- 9),
         (FloatR 530525 (- 16), FloatR (- 842679) (- 22)), FloatR 530526 (- 16),
         FloatR (- 842678) (- 22)),
        (FloatR 7040 (- 9), (FloatR 533346 (- 16), FloatR (- 837809) (- 22)),
         (FloatR 536151 (- 16), FloatR (- 832951) (- 22)), FloatR 7150 (- 9),
         (FloatR 533346 (- 16), FloatR (- 837809) (- 22)), FloatR 533347 (- 16),
         FloatR (- 837808) (- 22)),
        (FloatR 6930 (- 9), (FloatR 536150 (- 16), FloatR (- 832952) (- 22)),
         (FloatR 538939 (- 16), FloatR (- 828102) (- 22)), FloatR 7040 (- 9),
         (FloatR 536150 (- 16), FloatR (- 832952) (- 22)), FloatR 536151 (- 16),
         FloatR (- 832951) (- 22)),
        (FloatR 6820 (- 9), (FloatR 538938 (- 16), FloatR (- 828103) (- 22)),
         (FloatR 541711 (- 16), FloatR (- 823254) (- 22)), FloatR 6930 (- 9),
         (FloatR 538938 (- 16), FloatR (- 828103) (- 22)), FloatR 538939 (- 16),
         FloatR (- 828102) (- 22)),
        (FloatR 6710 (- 9), (FloatR 541710 (- 16), FloatR (- 823255) (- 22)),
         (FloatR 544467 (- 16), FloatR (- 818400) (- 22)), FloatR 6820 (- 9),
         (FloatR 541710 (- 16), FloatR (- 823255) (- 22)), FloatR 541711 (- 16),
         FloatR (- 823254) (- 22)),
        (FloatR 6600 (- 9), (FloatR 544466 (- 16), FloatR (- 818401) (- 22)),
         (FloatR 547206 (- 16), FloatR (- 813534) (- 22)), FloatR 6710 (- 9),
         (FloatR 544466 (- 16), FloatR (- 818401) (- 22)), FloatR 544467 (- 16),
         FloatR (- 818400) (- 22)),
        (FloatR 6490 (- 9), (FloatR 547205 (- 16), FloatR (- 813535) (- 22)),
         (FloatR 549929 (- 16), FloatR (- 808649) (- 22)), FloatR 6600 (- 9),
         (FloatR 547205 (- 16), FloatR (- 813535) (- 22)), FloatR 547206 (- 16),
         FloatR (- 813534) (- 22)),
        (FloatR 6380 (- 9), (FloatR 549927 (- 16), FloatR (- 808650) (- 22)),
         (FloatR 552635 (- 16), FloatR (- 803737) (- 22)), FloatR 6490 (- 9),
         (FloatR 549927 (- 16), FloatR (- 808650) (- 22)), FloatR 549929 (- 16),
         FloatR (- 808649) (- 22)),
        (FloatR 6270 (- 9), (FloatR 552634 (- 16), FloatR (- 803738) (- 22)),
         (FloatR 555325 (- 16), FloatR (- 798791) (- 22)), FloatR 6380 (- 9),
         (FloatR 552634 (- 16), FloatR (- 803738) (- 22)), FloatR 552635 (- 16),
         FloatR (- 803737) (- 22)),
        (FloatR 6160 (- 9), (FloatR 555324 (- 16), FloatR (- 798792) (- 22)),
         (FloatR 557998 (- 16), FloatR (- 793801) (- 22)), FloatR 6270 (- 9),
         (FloatR 555324 (- 16), FloatR (- 798792) (- 22)), FloatR 555325 (- 16),
         FloatR (- 798791) (- 22)),
        (FloatR 6050 (- 9), (FloatR 557997 (- 16), FloatR (- 793802) (- 22)),
         (FloatR 560654 (- 16), FloatR (- 788760) (- 22)), FloatR 6160 (- 9),
         (FloatR 557997 (- 16), FloatR (- 793802) (- 22)), FloatR 557998 (- 16),
         FloatR (- 793801) (- 22)),
        (FloatR 5940 (- 9), (FloatR 560653 (- 16), FloatR (- 788761) (- 22)),
         (FloatR 563293 (- 16), FloatR (- 783659) (- 22)), FloatR 6050 (- 9),
         (FloatR 560653 (- 16), FloatR (- 788761) (- 22)), FloatR 560654 (- 16),
         FloatR (- 788760) (- 22)),
        (FloatR 5830 (- 9), (FloatR 563292 (- 16), FloatR (- 783660) (- 22)),
         (FloatR 565915 (- 16), FloatR (- 778487) (- 22)), FloatR 5940 (- 9),
         (FloatR 563292 (- 16), FloatR (- 783660) (- 22)), FloatR 563293 (- 16),
         FloatR (- 783659) (- 22)),
        (FloatR 5720 (- 9), (FloatR 565914 (- 16), FloatR (- 778488) (- 22)),
         (FloatR 568520 (- 16), FloatR (- 773234) (- 22)), FloatR 5830 (- 9),
         (FloatR 565914 (- 16), FloatR (- 778488) (- 22)), FloatR 565915 (- 16),
         FloatR (- 778487) (- 22)),
        (FloatR 5610 (- 9), (FloatR 568519 (- 16), FloatR (- 773235) (- 22)),
         (FloatR 571107 (- 16), FloatR (- 767889) (- 22)), FloatR 5720 (- 9),
         (FloatR 568519 (- 16), FloatR (- 773235) (- 22)), FloatR 568520 (- 16),
         FloatR (- 773234) (- 22)),
        (FloatR 5500 (- 9), (FloatR 571106 (- 16), FloatR (- 767890) (- 22)),
         (FloatR 573675 (- 16), FloatR (- 762441) (- 22)), FloatR 5610 (- 9),
         (FloatR 571106 (- 16), FloatR (- 767890) (- 22)), FloatR 571107 (- 16),
         FloatR (- 767889) (- 22)),
        (FloatR 5390 (- 9), (FloatR 573674 (- 16), FloatR (- 762442) (- 22)),
         (FloatR 576225 (- 16), FloatR (- 756878) (- 22)), FloatR 5500 (- 9),
         (FloatR 573674 (- 16), FloatR (- 762442) (- 22)), FloatR 573675 (- 16),
         FloatR (- 762441) (- 22)),
        (FloatR 5280 (- 9), (FloatR 576224 (- 16), FloatR (- 756880) (- 22)),
         (FloatR 578757 (- 16), FloatR (- 751188) (- 22)), FloatR 5390 (- 9),
         (FloatR 576224 (- 16), FloatR (- 756880) (- 22)), FloatR 576225 (- 16),
         FloatR (- 756878) (- 22)),
        (FloatR 5170 (- 9), (FloatR 578756 (- 16), FloatR (- 751189) (- 22)),
         (FloatR 581269 (- 16), FloatR (- 745356) (- 22)), FloatR 5280 (- 9),
         (FloatR 578756 (- 16), FloatR (- 751189) (- 22)), FloatR 578757 (- 16),
         FloatR (- 751188) (- 22)),
        (FloatR 5060 (- 9), (FloatR 581268 (- 16), FloatR (- 745357) (- 22)),
         (FloatR 583761 (- 16), FloatR (- 739369) (- 22)), FloatR 5170 (- 9),
         (FloatR 581268 (- 16), FloatR (- 745357) (- 22)), FloatR 581269 (- 16),
         FloatR (- 745356) (- 22)),
        (FloatR 4950 (- 9), (FloatR 583760 (- 16), FloatR (- 739370) (- 22)),
         (FloatR 586233 (- 16), FloatR (- 733212) (- 22)), FloatR 5060 (- 9),
         (FloatR 583760 (- 16), FloatR (- 739370) (- 22)), FloatR 583761 (- 16),
         FloatR (- 739369) (- 22)),
        (FloatR 4840 (- 9), (FloatR 586232 (- 16), FloatR (- 733213) (- 22)),
         (FloatR 588683 (- 16), FloatR (- 726869) (- 22)), FloatR 4950 (- 9),
         (FloatR 586232 (- 16), FloatR (- 733213) (- 22)), FloatR 586233 (- 16),
         FloatR (- 733212) (- 22)),
        (FloatR 4730 (- 9), (FloatR 588682 (- 16), FloatR (- 726870) (- 22)),
         (FloatR 591112 (- 16), FloatR (- 720325) (- 22)), FloatR 4840 (- 9),
         (FloatR 588682 (- 16), FloatR (- 726870) (- 22)), FloatR 588683 (- 16),
         FloatR (- 726869) (- 22)),
        (FloatR 4620 (- 9), (FloatR 591111 (- 16), FloatR (- 720326) (- 22)),
         (FloatR 593519 (- 16), FloatR (- 713561) (- 22)), FloatR 4730 (- 9),
         (FloatR 591111 (- 16), FloatR (- 720326) (- 22)), FloatR 591112 (- 16),
         FloatR (- 720325) (- 22)),
        (FloatR 4510 (- 9), (FloatR 593518 (- 16), FloatR (- 713562) (- 22)),
         (FloatR 595903 (- 16), FloatR (- 706560) (- 22)), FloatR 4620 (- 9),
         (FloatR 593518 (- 16), FloatR (- 713562) (- 22)), FloatR 593519 (- 16),
         FloatR (- 713561) (- 22)),
        (FloatR 4400 (- 9), (FloatR 595902 (- 16), FloatR (- 706561) (- 22)),
         (FloatR 598263 (- 16), FloatR (- 699304) (- 22)), FloatR 4510 (- 9),
         (FloatR 595902 (- 16), FloatR (- 706561) (- 22)), FloatR 595903 (- 16),
         FloatR (- 706560) (- 22)),
        (FloatR 4290 (- 9), (FloatR 598262 (- 16), FloatR (- 699305) (- 22)),
         (FloatR 600598 (- 16), FloatR (- 691773) (- 22)), FloatR 4400 (- 9),
         (FloatR 598262 (- 16), FloatR (- 699305) (- 22)), FloatR 598263 (- 16),
         FloatR (- 699304) (- 22)),
        (FloatR 4180 (- 9), (FloatR 600597 (- 16), FloatR (- 691774) (- 22)),
         (FloatR 602907 (- 16), FloatR (- 683947) (- 22)), FloatR 4290 (- 9),
         (FloatR 600597 (- 16), FloatR (- 691774) (- 22)), FloatR 600598 (- 16),
         FloatR (- 691773) (- 22)),
        (FloatR 4070 (- 9), (FloatR 602906 (- 16), FloatR (- 683948) (- 22)),
         (FloatR 605189 (- 16), FloatR (- 675805) (- 22)), FloatR 4180 (- 9),
         (FloatR 602906 (- 16), FloatR (- 683948) (- 22)), FloatR 602907 (- 16),
         FloatR (- 683947) (- 22)),
        (FloatR 3960 (- 9), (FloatR 605188 (- 16), FloatR (- 675806) (- 22)),
         (FloatR 607444 (- 16), FloatR (- 667325) (- 22)), FloatR 4070 (- 9),
         (FloatR 605188 (- 16), FloatR (- 675806) (- 22)), FloatR 605189 (- 16),
         FloatR (- 675805) (- 22)),
        (FloatR 3850 (- 9), (FloatR 607443 (- 16), FloatR (- 667326) (- 22)),
         (FloatR 609669 (- 16), FloatR (- 658486) (- 22)), FloatR 3960 (- 9),
         (FloatR 607443 (- 16), FloatR (- 667326) (- 22)), FloatR 607444 (- 16),
         FloatR (- 667325) (- 22)),
        (FloatR 3740 (- 9), (FloatR 609668 (- 16), FloatR (- 658487) (- 22)),
         (FloatR 611864 (- 16), FloatR (- 649264) (- 22)), FloatR 3850 (- 9),
         (FloatR 609668 (- 16), FloatR (- 658487) (- 22)), FloatR 609669 (- 16),
         FloatR (- 658486) (- 22)),
        (FloatR 3630 (- 9), (FloatR 611863 (- 16), FloatR (- 649265) (- 22)),
         (FloatR 614028 (- 16), FloatR (- 639637) (- 22)), FloatR 3740 (- 9),
         (FloatR 611863 (- 16), FloatR (- 649265) (- 22)), FloatR 611864 (- 16),
         FloatR (- 649264) (- 22)),
        (FloatR 3520 (- 9), (FloatR 614027 (- 16), FloatR (- 639638) (- 22)),
         (FloatR 616158 (- 16), FloatR (- 629580) (- 22)), FloatR 3630 (- 9),
         (FloatR 614027 (- 16), FloatR (- 639638) (- 22)), FloatR 614028 (- 16),
         FloatR (- 639637) (- 22)),
        (FloatR 3410 (- 9), (FloatR 616157 (- 16), FloatR (- 629581) (- 22)),
         (FloatR 618254 (- 16), FloatR (- 619070) (- 22)), FloatR 3520 (- 9),
         (FloatR 616157 (- 16), FloatR (- 629581) (- 22)), FloatR 616158 (- 16),
         FloatR (- 629580) (- 22)),
        (FloatR 3300 (- 9), (FloatR 618253 (- 16), FloatR (- 619071) (- 22)),
         (FloatR 620314 (- 16), FloatR (- 608083) (- 22)), FloatR 3410 (- 9),
         (FloatR 618253 (- 16), FloatR (- 619071) (- 22)), FloatR 618254 (- 16),
         FloatR (- 619070) (- 22)),
        (FloatR 3190 (- 9), (FloatR 620313 (- 16), FloatR (- 608084) (- 22)),
         (FloatR 622336 (- 16), FloatR (- 596594) (- 22)), FloatR 3300 (- 9),
         (FloatR 620313 (- 16), FloatR (- 608084) (- 22)), FloatR 620314 (- 16),
         FloatR (- 608083) (- 22)),
        (FloatR 3080 (- 9), (FloatR 622335 (- 16), FloatR (- 596595) (- 22)),
         (FloatR 624319 (- 16), FloatR (- 584581) (- 22)), FloatR 3190 (- 9),
         (FloatR 622335 (- 16), FloatR (- 596595) (- 22)), FloatR 622336 (- 16),
         FloatR (- 596594) (- 22)),
        (FloatR 2970 (- 9), (FloatR 624318 (- 16), FloatR (- 584582) (- 22)),
         (FloatR 626260 (- 16), FloatR (- 572019) (- 22)), FloatR 3080 (- 9),
         (FloatR 624318 (- 16), FloatR (- 584582) (- 22)), FloatR 624319 (- 16),
         FloatR (- 584581) (- 22)),
        (FloatR 2860 (- 9), (FloatR 626259 (- 16), FloatR (- 572020) (- 22)),
         (FloatR 628159 (- 16), FloatR (- 558886) (- 22)), FloatR 2970 (- 9),
         (FloatR 626259 (- 16), FloatR (- 572020) (- 22)), FloatR 626260 (- 16),
         FloatR (- 572019) (- 22)),
        (FloatR 2750 (- 9), (FloatR 628158 (- 16), FloatR (- 558888) (- 22)),
         (FloatR 630012 (- 16), FloatR (- 545161) (- 22)), FloatR 2860 (- 9),
         (FloatR 628158 (- 16), FloatR (- 558888) (- 22)), FloatR 628159 (- 16),
         FloatR (- 558886) (- 22)),
        (FloatR 2640 (- 9), (FloatR 630011 (- 16), FloatR (- 545162) (- 22)),
         (FloatR 631818 (- 16), FloatR (- 530822) (- 22)), FloatR 2750 (- 9),
         (FloatR 630011 (- 16), FloatR (- 545162) (- 22)), FloatR 630012 (- 16),
         FloatR (- 545161) (- 22)),
        (FloatR 2530 (- 9), (FloatR 631817 (- 16), FloatR (- 530823) (- 22)),
         (FloatR 633575 (- 16), FloatR (- 1031701) (- 23)), FloatR 2640 (- 9),
         (FloatR 631817 (- 16), FloatR (- 530823) (- 22)), FloatR 631818 (- 16),
         FloatR (- 530822) (- 22)),
        (FloatR 2420 (- 9), (FloatR 633574 (- 16), FloatR (- 1031702) (- 23)),
         (FloatR 635281 (- 16), FloatR (- 1000458) (- 23)), FloatR 2530 (- 9),
         (FloatR 633574 (- 16), FloatR (- 1031702) (- 23)), FloatR 633575 (- 16),
         FloatR (- 1031701) (- 23)),
        (FloatR 2310 (- 9), (FloatR 635280 (- 16), FloatR (- 1000459) (- 23)),
         (FloatR 636933 (- 16), FloatR (- 967884) (- 23)), FloatR 2420 (- 9),
         (FloatR 635280 (- 16), FloatR (- 1000459) (- 23)), FloatR 635281 (- 16),
         FloatR (- 1000458) (- 23)),
        (FloatR 2200 (- 9), (FloatR 636932 (- 16), FloatR (- 967885) (- 23)),
         (FloatR 638529 (- 16), FloatR (- 933955) (- 23)), FloatR 2310 (- 9),
         (FloatR 636932 (- 16), FloatR (- 967885) (- 23)), FloatR 636933 (- 16),
         FloatR (- 967884) (- 23)),
        (FloatR 2090 (- 9), (FloatR 638528 (- 16), FloatR (- 933956) (- 23)),
         (FloatR 640067 (- 16), FloatR (- 898650) (- 23)), FloatR 2200 (- 9),
         (FloatR 638528 (- 16), FloatR (- 933956) (- 23)), FloatR 638529 (- 16),
         FloatR (- 933955) (- 23)),
        (FloatR 1980 (- 9), (FloatR 640066 (- 16), FloatR (- 898651) (- 23)),
         (FloatR 641545 (- 16), FloatR (- 861955) (- 23)), FloatR 2090 (- 9),
         (FloatR 640066 (- 16), FloatR (- 898651) (- 23)), FloatR 640067 (- 16),
         FloatR (- 898650) (- 23)),
        (FloatR 1870 (- 9), (FloatR 641544 (- 16), FloatR (- 861957) (- 23)),
         (FloatR 642960 (- 16), FloatR (- 823865) (- 23)), FloatR 1980 (- 9),
         (FloatR 641544 (- 16), FloatR (- 861957) (- 23)), FloatR 641545 (- 16),
         FloatR (- 861955) (- 23)),
        (FloatR 1760 (- 9), (FloatR 642959 (- 16), FloatR (- 823866) (- 23)),
         (FloatR 644310 (- 16), FloatR (- 784380) (- 23)), FloatR 1870 (- 9),
         (FloatR 642959 (- 16), FloatR (- 823866) (- 23)), FloatR 642960 (- 16),
         FloatR (- 823865) (- 23)),
        (FloatR 1650 (- 9), (FloatR 644309 (- 16), FloatR (- 784382) (- 23)),
         (FloatR 645592 (- 16), FloatR (- 743511) (- 23)), FloatR 1760 (- 9),
         (FloatR 644309 (- 16), FloatR (- 784381) (- 23)), FloatR 644310 (- 16),
         FloatR (- 784380) (- 23)),
        (FloatR 1540 (- 9), (FloatR 645591 (- 16), FloatR (- 743512) (- 23)),
         (FloatR 646805 (- 16), FloatR (- 701274) (- 23)), FloatR 1650 (- 9),
         (FloatR 645591 (- 16), FloatR (- 743512) (- 23)), FloatR 645592 (- 16),
         FloatR (- 743511) (- 23)),
        (FloatR 1430 (- 9), (FloatR 646804 (- 16), FloatR (- 701275) (- 23)),
         (FloatR 647946 (- 16), FloatR (- 657699) (- 23)), FloatR 1540 (- 9),
         (FloatR 646804 (- 16), FloatR (- 701275) (- 23)), FloatR 646805 (- 16),
         FloatR (- 701274) (- 23)),
        (FloatR 1320 (- 9), (FloatR 647945 (- 16), FloatR (- 657700) (- 23)),
         (FloatR 649012 (- 16), FloatR (- 612824) (- 23)), FloatR 1430 (- 9),
         (FloatR 647945 (- 16), FloatR (- 657700) (- 23)), FloatR 647946 (- 16),
         FloatR (- 657699) (- 23)),
        (FloatR 1210 (- 9), (FloatR 649011 (- 16), FloatR (- 612825) (- 23)),
         (FloatR 650002 (- 16), FloatR (- 566695) (- 23)), FloatR 1320 (- 9),
         (FloatR 649011 (- 16), FloatR (- 612825) (- 23)), FloatR 649012 (- 16),
         FloatR (- 612824) (- 23)),
        (FloatR 1100 (- 9), (FloatR 650001 (- 16), FloatR (- 566696) (- 23)),
         (FloatR 650914 (- 16), FloatR (- 1038743) (- 24)), FloatR 1210 (- 9),
         (FloatR 650001 (- 16), FloatR (- 566696) (- 23)), FloatR 650002 (- 16),
         FloatR (- 566695) (- 23)),
        (FloatR 990 (- 9), (FloatR 650913 (- 16), FloatR (- 1038744) (- 24)),
         (FloatR 651745 (- 16), FloatR (- 941842) (- 24)), FloatR 1100 (- 9),
         (FloatR 650913 (- 16), FloatR (- 1038744) (- 24)), FloatR 650914 (- 16),
         FloatR (- 1038743) (- 24)),
        (FloatR 880 (- 9), (FloatR 651744 (- 16), FloatR (- 941843) (- 24)),
         (FloatR 652494 (- 16), FloatR (- 842845) (- 24)), FloatR 990 (- 9),
         (FloatR 651744 (- 16), FloatR (- 941843) (- 24)), FloatR 651745 (- 16),
         FloatR (- 941842) (- 24)),
        (FloatR 770 (- 9), (FloatR 652493 (- 16), FloatR (- 842846) (- 24)),
         (FloatR 653159 (- 16), FloatR (- 741927) (- 24)), FloatR 880 (- 9),
         (FloatR 652493 (- 16), FloatR (- 842846) (- 24)), FloatR 652494 (- 16),
         FloatR (- 842845) (- 24)),
        (FloatR 660 (- 9), (FloatR 653158 (- 16), FloatR (- 741928) (- 24)),
         (FloatR 653739 (- 16), FloatR (- 639284) (- 24)), FloatR 770 (- 9),
         (FloatR 653158 (- 16), FloatR (- 741928) (- 24)), FloatR 653159 (- 16),
         FloatR (- 741927) (- 24)),
        (FloatR 550 (- 9), (FloatR 653738 (- 16), FloatR (- 639285) (- 24)),
         (FloatR 654232 (- 16), FloatR (- 535127) (- 24)), FloatR 660 (- 9),
         (FloatR 653738 (- 16), FloatR (- 639285) (- 24)), FloatR 653739 (- 16),
         FloatR (- 639284) (- 24)),
        (FloatR 440 (- 9), (FloatR 654231 (- 16), FloatR (- 535128) (- 24)),
         (FloatR 654637 (- 16), FloatR (- 859366) (- 25)), FloatR 550 (- 9),
         (FloatR 654231 (- 16), FloatR (- 535128) (- 24)), FloatR 654232 (- 16),
         FloatR (- 535127) (- 24)),
        (FloatR 330 (- 9), (FloatR 654636 (- 16), FloatR (- 859367) (- 25)),
         (FloatR 654953 (- 16), FloatR (- 646385) (- 25)), FloatR 440 (- 9),
         (FloatR 654636 (- 16), FloatR (- 859367) (- 25)), FloatR 654637 (- 16),
         FloatR (- 859366) (- 25)),
        (FloatR 220 (- 9), (FloatR 654952 (- 16), FloatR (- 646387) (- 25)),
         (FloatR 655179 (- 16), FloatR (- 863632) (- 26)), FloatR 330 (- 9),
         (FloatR 654952 (- 16), FloatR (- 646387) (- 25)), FloatR 654953 (- 16),
         FloatR (- 646386) (- 25)),
        (FloatR 110 (- 9), (FloatR 655178 (- 16), FloatR (- 863633) (- 26)),
         (FloatR 655315 (- 16), FloatR (- 864707) (- 27)), FloatR 220 (- 9),
         (FloatR 655178 (- 16), FloatR (- 863633) (- 26)), FloatR 655179 (- 16),
         FloatR (- 863632) (- 26)),
        (FloatR 0 0, (FloatR 655314 (- 16), FloatR (- 864708) (- 27)),
         (FloatR 655360 (- 16), FloatR 869715 (- 57)), FloatR 110 (- 9),
         (FloatR 655314 (- 16), FloatR (- 864708) (- 27)), FloatR 655315 (- 16),
         FloatR (- 864707) (- 27))])"
  oops --"by eval"

end
